@@ -1,6 +1,7 @@
 """
 Functions which help the functions within the parser module
 """
+
 import ast
 from ast import (
     AnnAssign,
@@ -21,7 +22,7 @@ from operator import attrgetter, eq, itemgetter
 from types import FunctionType
 
 from cdd.ast_utils import NoneStr, column_type2typ, get_value, json_type2typ
-from cdd.pure_utils import lstrip_namespace, none_types, rpartial
+from cdd.pure_utils import lstrip_namespace, none_types, rpartial, simple_types
 from cdd.source_transformer import to_code
 
 lstrip_typings = partial(lstrip_namespace, namespaces=("typings.", "_extensions."))
@@ -61,13 +62,16 @@ def ir_merge(target, other):
         for name in other_params.keys() & target_params.keys():
             if not target_params[name].get("doc") and other_params[name].get("doc"):
                 target_params[name]["doc"] = other_params[name]["doc"]
-            if target_params[name].get("typ") is None and other_params[name].get("typ"):
+
+            if other_params[name].get("typ") is not None and (
+                target_params[name].get("typ") is None
+                or target_params[name]["typ"] in simple_types
+                and other_params[name]["typ"] not in simple_types
+            ):
                 target_params[name]["typ"] = other_params[name]["typ"]
             if (
                 target_params[name].get("default") in none_types
-                and "default" in other_params[name]
-                and other_params[name]["default"]
-                not in frozenset((None, "None", "(None)"))
+                and other_params[name].get("default") is not None
             ):
                 target_params[name]["default"] = other_params[name]["default"]
 
@@ -369,8 +373,27 @@ def infer(*args, **kwargs):
             return "sqlalchemy_table"
 
 
+def get_source(obj):
+    """
+    Call inspect.getsource and raise an error unless class definition could not be found
+
+    :param obj: object to inspect
+    :type obj: ```Any```
+
+    :returns: The source
+    :rtype: ```str```
+    """
+    try:
+        return getsource(obj)
+    except OSError as e:
+        if e.args and e.args[0] == "could not find class definition":
+            return None
+        raise
+
+
 __all__ = [
     "column_call_to_param",
+    "get_source",
     "ir_merge",
     "infer",
     "json_schema_property_to_param",
